from django.conf.urls import patterns, url

from django.contrib import admin

admin.autodiscover()

urlpatterns = patterns(
    'demo.views',
    url(r'^success/', 'g2s_success', name='g2s-success'),
    url(r'^pending/', 'g2s_pending', name='g2s-pending'),
    url(r'^error/', 'g2s_error', name='g2s-error'),
    url(r'^back/', 'g2s_back', name='g2s-back'),
    url(r'^$', 'g2s_index', name='g2s-index'),
)



# -*- encoding: utf-8 -*-

from django.conf import settings


def get_settings(key, default):
    return getattr(settings, key, default)


MERCHANT_ID = get_settings('G2S_MERCHANT_ID', '')
MERCHANT_SITE_ID = get_settings('G2S_MERCHANT_SITE_ID', '')
CURRENCY = get_settings('G2S_CURRENCY', '')
SECRET_KEY = get_settings('G2S_SECRET_KEY', '')
API_VERSION = get_settings('G2S_API_VERSION', '3.0.0')
LIVE_URL = get_settings(
    'G2S_LIVE_URL', 'https://secure.gate2shop.com/ppp/purchase.do')

MERCHANT_LOCALE = get_settings('G2S_MERCHANT_LOCALE', 'en_US')
MERCHANT_ENCODING = get_settings('G2S_MERCHANT_ENCODING', 'utf-8')

MERCHANT_LOCALES = [
    'en_US',
    'zh_ZN',
    'it_IT',
    'iw_IL',
    'ar_AA',
    'Es_ES',
    'ru_RU',
    'nl_NL',
    'pt_BR',
    'tr_TR',
    'lt_LT',
    'ro_RO',
    'pl_PL',
    'fr_FR',
    'bg_BG',
    'hr_HR',
    'de_DE',
    'da_DK',
    'ja_JP',
    'sr_RS',
    'sv_SE',
    'sl_SI'
]

MERCHANT_CURRENCIES = [
    'AUD'
    'CAD'
    'CHF'
    'DKK',
    'EUR',
    'GBP',
    'NOK',
    'SEK',
    'USD',
]



# -*- coding: utf-8 -*-

from hashlib import md5

from django.core.exceptions import ValidationError
from django.db import models

from g2s import defaults
from g2s import signals


class G2STransaction(models.Model):
    Status = models.CharField(max_length=10)
    totalAmount = models.DecimalField(
        max_digits=17, decimal_places=2, default='0.00')
    TransactionID = models.BigIntegerField()
    ErrCode = models.SmallIntegerField()
    ExErrCode = models.SmallIntegerField()
    Error = models.CharField(max_length=255, null=True, blank=True, default='')
    AuthCode = models.PositiveIntegerField(null=True, blank=True, default=0)
    Reason = models.CharField(max_length=255, null=True, blank=True)
    Token = models.TextField(null=True, blank=True)
    responsechecksum = models.CharField(max_length=50, db_index=True)
    ppp_status = models.CharField(max_length=10)
    PPP_TransactionID = models.BigIntegerField()
    ReasonCode = models.SmallIntegerField()
    advanceResponseChecksum = models.CharField(max_length=255)
    cardCompany = models.CharField(max_length=255, null=True, blank=True)

    city = models.CharField(max_length=30)
    country = models.CharField(max_length=20)

    first_name = models.CharField(max_length=30, null=True, blank=True)
    last_name = models.CharField(max_length=40, null=True, blank=True)

    merchantLocale = models.CharField(
        max_length=5, default=defaults.MERCHANT_LOCALE)
    currency = models.CharField(
        max_length=3, default=defaults.CURRENCY)
    message = models.TextField()

    dynamicDescriptor = models.CharField(max_length=255, null=True, blank=True)
    zip = models.CharField(max_length=18)
    tokenId = models.CharField(max_length=255, null=True, blank=True)
    payment_method = models.CharField(max_length=256)
    requestVersion = models.CharField(max_length=10, null=True, blank=True)
    email = models.EmailField(max_length=100)
    responseTimeStamp = models.DateTimeField()
    productId = models.PositiveIntegerField(null=True, blank=True)
    merchant_site_id = models.BigIntegerField()
    merchant_id = models.BigIntegerField()
    nameOnCard = models.CharField(max_length=100, null=True, blank=True)
    uniqueCC = models.CharField(max_length=255, null=True, blank=True)

    def _validate_response_checksum(self):
        fields = [
            defaults.SECRET_KEY, self.totalAmount, self.currency,
            self.responseTimeStamp.strftime('%Y-%m-%d.%H:%M:%S'),
            self.PPP_TransactionID, self.Status, self.productId or ''
        ]
        m = md5()
        m.update(''.join(map(str, fields)))
        if m.hexdigest() != self.advanceResponseChecksum:
            raise ValidationError('Error')

    def _send_signal(self):
        if self.Status == 'APPROVED':
            signals.g2s_payment_was_successful.send(sender=self)
        signals.g2s_signal.send(sender=self)

    def clean(self):
        self._validate_response_checksum()

    def save(self, *args, **kwargs):
        transaction_is_exists = self._default_manager.filter(
            TransactionID=self.TransactionID).exists()

        if not transaction_is_exists:
            super(G2STransaction, self).save(*args, **kwargs)
            return self._send_signal()
        return False

    def __unicode__(self):
        return str(self.PPP_TransactionID)



from django.shortcuts import render, HttpResponse
from g2s.forms import G2SForm


def g2s_index(request):
    # this is what user wants to buy
    items_list = [
        {
            'item_name': 'Test',
            'item_amount': 1.11,
            'item_quantity': 1,
        },
    ]

    # this data you can get from user profile or from custom user model
    payment_details = {
        'country': 'Russia',
        'city': 'Moscow',
        'address1': 'Moscow, Arbat',
        'zip': '121099',
        'first_name': 'Ivan',
        'last_name': 'Ivanov',
        'email': 'ivanov.ivan@yandex.ru',
        'phone1': '+79031234567',
        'total_amount': 1.11,
        'user_token_id': request.user.pk or 1,

        # all available methods on http://www.g2s.com/world-wide-payments/
        'payment_method': 'cc_card', # cc_card, dc_card, giro
        'productId': 1,
    }

    form = G2SForm(items_list, initial=payment_details)
    return render(request, "g2s/order.html", {"form": form})


def g2s_success(request):
    """
    from g2s.forms import G2STransactionForm

    try:
        form = G2STransactionForm(request.GET)
        if form.is_valid() and form.save():
            return HttpResponse("Success")
    except Exception, msg:
        print '[g2s]', msg.__str__()
    return HttpResponse('Error')
    """
    return HttpResponse("Success")

def g2s_pending(request):
    return HttpResponse("Pending")


def g2s_error(request):
    return HttpResponse("Error")


def g2s_back(request):
    return HttpResponse("Back")



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'G2STransaction'
        db.create_table(u'g2s_g2stransaction', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('Status', self.gf('django.db.models.fields.CharField')(max_length=10)),
            ('totalAmount', self.gf('django.db.models.fields.DecimalField')(default='0.00', max_digits=17, decimal_places=2)),
            ('TransactionID', self.gf('django.db.models.fields.BigIntegerField')()),
            ('ErrCode', self.gf('django.db.models.fields.SmallIntegerField')()),
            ('ExErrCode', self.gf('django.db.models.fields.SmallIntegerField')()),
            ('Error', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('AuthCode', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('Reason', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('Token', self.gf('django.db.models.fields.TextField')()),
            ('responsechecksum', self.gf('django.db.models.fields.CharField')(max_length=50, db_index=True)),
            ('ppp_status', self.gf('django.db.models.fields.CharField')(max_length=10)),
            ('PPP_TransactionID', self.gf('django.db.models.fields.BigIntegerField')()),
            ('ReasonCode', self.gf('django.db.models.fields.SmallIntegerField')()),
            ('advanceResponseChecksum', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('cardCompany', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('city', self.gf('django.db.models.fields.CharField')(max_length=30)),
            ('country', self.gf('django.db.models.fields.CharField')(max_length=20)),
            ('first_name', self.gf('django.db.models.fields.CharField')(max_length=30, null=True, blank=True)),
            ('last_name', self.gf('django.db.models.fields.CharField')(max_length=40, null=True, blank=True)),
            ('merchantLocale', self.gf('django.db.models.fields.CharField')(default='en_US', max_length=5)),
            ('currency', self.gf('django.db.models.fields.CharField')(default='USD', max_length=3)),
            ('message', self.gf('django.db.models.fields.TextField')()),
            ('dynamicDescriptor', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('zip', self.gf('django.db.models.fields.CharField')(max_length=18)),
            ('tokenId', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('payment_method', self.gf('django.db.models.fields.CharField')(max_length=256)),
            ('requestVersion', self.gf('django.db.models.fields.CharField')(max_length=10)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=100)),
            ('responseTimeStamp', self.gf('django.db.models.fields.DateTimeField')()),
            ('productId', self.gf('django.db.models.fields.PositiveIntegerField')(null=True, blank=True)),
            ('merchant_site_id', self.gf('django.db.models.fields.BigIntegerField')()),
            ('merchant_id', self.gf('django.db.models.fields.BigIntegerField')()),
            ('nameOnCard', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('uniqueCC', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal(u'g2s', ['G2STransaction'])


    def backwards(self, orm):
        # Deleting model 'G2STransaction'
        db.delete_table(u'g2s_g2stransaction')


    models = {
        u'g2s.g2stransaction': {
            'AuthCode': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'ErrCode': ('django.db.models.fields.SmallIntegerField', [], {}),
            'Error': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'ExErrCode': ('django.db.models.fields.SmallIntegerField', [], {}),
            'Meta': {'object_name': 'G2STransaction'},
            'PPP_TransactionID': ('django.db.models.fields.BigIntegerField', [], {}),
            'Reason': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'ReasonCode': ('django.db.models.fields.SmallIntegerField', [], {}),
            'Status': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'Token': ('django.db.models.fields.TextField', [], {}),
            'TransactionID': ('django.db.models.fields.BigIntegerField', [], {}),
            'advanceResponseChecksum': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'cardCompany': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'city': ('django.db.models.fields.CharField', [], {'max_length': '30'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            'currency': ('django.db.models.fields.CharField', [], {'default': "'USD'", 'max_length': '3'}),
            'dynamicDescriptor': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '100'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '40', 'null': 'True', 'blank': 'True'}),
            'merchantLocale': ('django.db.models.fields.CharField', [], {'default': "'en_US'", 'max_length': '5'}),
            'merchant_id': ('django.db.models.fields.BigIntegerField', [], {}),
            'merchant_site_id': ('django.db.models.fields.BigIntegerField', [], {}),
            'message': ('django.db.models.fields.TextField', [], {}),
            'nameOnCard': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'payment_method': ('django.db.models.fields.CharField', [], {'max_length': '256'}),
            'ppp_status': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'productId': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'requestVersion': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'responseTimeStamp': ('django.db.models.fields.DateTimeField', [], {}),
            'responsechecksum': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'tokenId': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'totalAmount': ('django.db.models.fields.DecimalField', [], {'default': "'0.00'", 'max_digits': '17', 'decimal_places': '2'}),
            'uniqueCC': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'zip': ('django.db.models.fields.CharField', [], {'max_length': '18'})
        }
    }

    complete_apps = ['g2s']


# -*- coding: utf-8 -*-
from django.utils.encoding import force_unicode
from django.utils.safestring import mark_safe
from django import forms


class ExistHiddenInput(forms.HiddenInput):
    def render(self, name, value, attrs=None):
        if value is None:
            return ''
        final_attrs = self.build_attrs(attrs, type=self.input_type, name=name)
        final_attrs['value'] = force_unicode(self._format_value(value))
        return mark_safe(u'<input%s />' % forms.util.flatatt(final_attrs))



from django.forms.models import model_to_dict
from g2s.signals import g2s_payment_was_successful
from pprint import pprint


def transaction_result(sender, **kwargs):
    if sender.Status == 'APPROVED':
        pprint(model_to_dict(sender))


g2s_payment_was_successful.connect(
    transaction_result, dispatch_uid="demo.models.transaction_result")



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'G2STransaction.dynamicDescriptor'
        db.alter_column(u'g2s_g2stransaction', 'dynamicDescriptor', self.gf('django.db.models.fields.CharField')(max_length=255, null=True))

        # Changing field 'G2STransaction.requestVersion'
        db.alter_column(u'g2s_g2stransaction', 'requestVersion', self.gf('django.db.models.fields.CharField')(max_length=10, null=True))

        # Changing field 'G2STransaction.cardCompany'
        db.alter_column(u'g2s_g2stransaction', 'cardCompany', self.gf('django.db.models.fields.CharField')(max_length=255, null=True))

        # Changing field 'G2STransaction.Token'
        db.alter_column(u'g2s_g2stransaction', 'Token', self.gf('django.db.models.fields.TextField')(null=True))

        # Changing field 'G2STransaction.tokenId'
        db.alter_column(u'g2s_g2stransaction', 'tokenId', self.gf('django.db.models.fields.CharField')(max_length=255, null=True))

        # Changing field 'G2STransaction.nameOnCard'
        db.alter_column(u'g2s_g2stransaction', 'nameOnCard', self.gf('django.db.models.fields.CharField')(max_length=100, null=True))

        # Changing field 'G2STransaction.uniqueCC'
        db.alter_column(u'g2s_g2stransaction', 'uniqueCC', self.gf('django.db.models.fields.CharField')(max_length=255, null=True))

    def backwards(self, orm):

        # Changing field 'G2STransaction.dynamicDescriptor'
        db.alter_column(u'g2s_g2stransaction', 'dynamicDescriptor', self.gf('django.db.models.fields.CharField')(default='None', max_length=255))

        # Changing field 'G2STransaction.requestVersion'
        db.alter_column(u'g2s_g2stransaction', 'requestVersion', self.gf('django.db.models.fields.CharField')(default='3.0.0', max_length=10))

        # Changing field 'G2STransaction.cardCompany'
        db.alter_column(u'g2s_g2stransaction', 'cardCompany', self.gf('django.db.models.fields.CharField')(default='None', max_length=255))

        # Changing field 'G2STransaction.Token'
        db.alter_column(u'g2s_g2stransaction', 'Token', self.gf('django.db.models.fields.TextField')(default='None'))

        # Changing field 'G2STransaction.tokenId'
        db.alter_column(u'g2s_g2stransaction', 'tokenId', self.gf('django.db.models.fields.CharField')(default='None', max_length=255))

        # Changing field 'G2STransaction.nameOnCard'
        db.alter_column(u'g2s_g2stransaction', 'nameOnCard', self.gf('django.db.models.fields.CharField')(default='None', max_length=100))

        # Changing field 'G2STransaction.uniqueCC'
        db.alter_column(u'g2s_g2stransaction', 'uniqueCC', self.gf('django.db.models.fields.CharField')(default='None', max_length=255))

    models = {
        u'g2s.g2stransaction': {
            'AuthCode': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'}),
            'ErrCode': ('django.db.models.fields.SmallIntegerField', [], {}),
            'Error': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'ExErrCode': ('django.db.models.fields.SmallIntegerField', [], {}),
            'Meta': {'object_name': 'G2STransaction'},
            'PPP_TransactionID': ('django.db.models.fields.BigIntegerField', [], {}),
            'Reason': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'ReasonCode': ('django.db.models.fields.SmallIntegerField', [], {}),
            'Status': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'Token': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'TransactionID': ('django.db.models.fields.BigIntegerField', [], {}),
            'advanceResponseChecksum': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'cardCompany': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'city': ('django.db.models.fields.CharField', [], {'max_length': '30'}),
            'country': ('django.db.models.fields.CharField', [], {'max_length': '20'}),
            'currency': ('django.db.models.fields.CharField', [], {'default': "'USD'", 'max_length': '3'}),
            'dynamicDescriptor': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '100'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '40', 'null': 'True', 'blank': 'True'}),
            'merchantLocale': ('django.db.models.fields.CharField', [], {'default': "'en_US'", 'max_length': '5'}),
            'merchant_id': ('django.db.models.fields.BigIntegerField', [], {}),
            'merchant_site_id': ('django.db.models.fields.BigIntegerField', [], {}),
            'message': ('django.db.models.fields.TextField', [], {}),
            'nameOnCard': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}),
            'payment_method': ('django.db.models.fields.CharField', [], {'max_length': '256'}),
            'ppp_status': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'productId': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'requestVersion': ('django.db.models.fields.CharField', [], {'max_length': '10', 'null': 'True', 'blank': 'True'}),
            'responseTimeStamp': ('django.db.models.fields.DateTimeField', [], {}),
            'responsechecksum': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'tokenId': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'totalAmount': ('django.db.models.fields.DecimalField', [], {'default': "'0.00'", 'max_digits': '17', 'decimal_places': '2'}),
            'uniqueCC': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'zip': ('django.db.models.fields.CharField', [], {'max_length': '18'})
        }
    }

    complete_apps = ['g2s']


# -*- coding: utf-8 -*-

from django.contrib import admin

from g2s.models import G2STransaction


class G2STransactionAdmin(admin.ModelAdmin):

    list_display = [
        'TransactionID', 'first_name', 'last_name', 'totalAmount',
        'currency', 'payment_method', 'Status',
    ]
    date_hierarchy = 'responseTimeStamp'
    list_filter = ['responseTimeStamp']
    search_fields = [
        'TransactionID', 'first_name', 'last_name',
        'totalAmount', 'PPP_TransactionID', 'payment_method'
    ]

    def __init__(self, model, admin_site):
        super(G2STransactionAdmin, self).__init__(model, admin_site)

        self.readonly_fields = [field.name for field in model._meta.fields]
        self.readonly_model = model

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return request.method != 'POST'


admin.site.register(G2STransaction, G2STransactionAdmin)



# -*- coding: utf-8 -*-

from datetime import datetime
from hashlib import md5

from django.utils.safestring import mark_safe
from django import forms

from g2s.fields import ExistHiddenInput
from g2s.models import G2STransaction
from g2s import defaults


class G2SForm(forms.Form):
    merchant_id = forms.IntegerField(initial=defaults.MERCHANT_ID)
    merchant_site_id = forms.IntegerField(
        initial=defaults.MERCHANT_SITE_ID)
    total_amount = forms.DecimalField(max_digits=17, decimal_places=2)
    customSiteName = forms.CharField(max_length=50)
    user_token_id = forms.IntegerField()
    user_token = forms.CharField(max_length=50, initial='auto')
    productId = forms.IntegerField(required=False)

    version = forms.CharField(max_length=10, initial=defaults.API_VERSION)
    checksum = forms.CharField(max_length=50)
    time_stamp = forms.CharField()
    currency = forms.CharField(
        max_length=3, initial=defaults.CURRENCY)

    payment_method = forms.CharField(max_length=256, initial='cc_card')
    merchantLocale = forms.CharField(
        max_length=5, initial=defaults.MERCHANT_LOCALE)

    encoding = forms.CharField(
        max_length=20, initial=defaults.MERCHANT_ENCODING)
    webMasterId = forms.CharField(max_length=255, required=False)

    first_name = forms.CharField(max_length=30, required=False)
    last_name = forms.CharField(max_length=40, required=False)
    email = forms.EmailField(max_length=100)
    address1 = forms.CharField(max_length=60)
    address2 = forms.CharField(max_length=60, required=False)
    city = forms.CharField(max_length=30)
    country = forms.CharField(max_length=20)
    state = forms.CharField(max_length=20, required=False)
    zip = forms.CharField(max_length=18)
    phone1 = forms.CharField(max_length=18)
    phone2 = forms.CharField(max_length=18, required=False)
    phone3 = forms.CharField(max_length=18, required=False)

    def __init__(self, items_list, *args, **kwargs):
        super(G2SForm, self).__init__(*args, **kwargs)

        self.items_list = items_list
        self.initial = kwargs.get('initial')

        self.__add_items()
        self.__add_number_of_items()
        self.__add_non_exists()
        self.__set_time_stamp()
        self.__set_checksum()
        self.__hide_field()

    def __set_checksum(self):
        items = ''
        for item in self.items_list:
            items += item['item_name'] + str(
                item['item_amount']) + str(item['item_quantity'])

        m = md5()
        m.update(
            defaults.SECRET_KEY + defaults.MERCHANT_ID +
            str(self.initial['currency']) +
            str(self.initial['total_amount']) + items +
            str(self.initial['user_token_id']) +
            self.fields['time_stamp'].initial
        )
        self.fields['checksum'].initial = m.hexdigest()

    def __set_time_stamp(self):
        self.fields['time_stamp'].initial = datetime.now().strftime(
            '%Y-%m-%d %H:%M:%S')

    def __add_non_exists(self):
        for key, val in self.initial.items():
            if key not in self.fields:
                self.fields[key] = forms.CharField(
                    initial=val, widget=ExistHiddenInput())

    def __add_number_of_items(self):
        self.fields['numberofitems'] = forms.IntegerField(
            initial=len(self.items_list))

    def __add_items(self):
        for i, item in enumerate(self.items_list, start=1):
            for key, val in item.items():
                self.fields['%s_%d' % (key, i)] = forms.CharField(initial=val)

    def __hide_field(self):
        for field in self.fields.keys():
            if self.fields.get(field):
                self.fields[field].widget = ExistHiddenInput()

    def render(self):
        return mark_safe(
            u"""
            <form action="%s" method="get">
            %s
            <input type="submit" value="Go">
            </form>""" % (self.post_action(), self.as_p())
        )

    @staticmethod
    def post_action():
        return mark_safe(defaults.LIVE_URL)


class G2STransactionForm(forms.ModelForm):
    responseTimeStamp = forms.DateTimeField(
        input_formats=['%Y-%m-%d.%H:%M:%S'])

    class Meta:
        model = G2STransaction



# -*- coding: utf-8 -*-

from django.http import HttpResponse, HttpResponseForbidden
from g2s.forms import G2STransactionForm


def save_g2s_transaction(request):
    try:
        form = G2STransactionForm(request.GET)
        if form.is_valid() and form.save():
            return HttpResponse("OK")
        print'[g2s]', dict(form.errors)
    except Exception, msg:
        print '[g2s]', msg.__str__()
    return HttpResponseForbidden()



from setuptools import setup, find_packages
from g2s import get_version

setup(
    name='django-gate2shop',
    version=get_version(),
    keywords="payment django g2s gate2shop",
    author='GoTLiuM InSPiRiT',
    author_email='gotlium@gmail.com',
    maintainer="GoTLiuM InSPiRiT",
    maintainer_email="gotlium@gmail.com",
    description='Gate2Shop gateway for accept payments on your website.',
    url='https://github.com/gotlium/django-gate2shop',
    packages=find_packages(exclude=['demo']),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Django>=1.4',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python',
    ],
)
